/**
 * AjoutArticleScreen.tsx
 * @author Mattias EYHERABIDE
 */

import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Button, TextInput } from 'react-native';
import { BarCodeScanner } from 'expo-barcode-scanner';
import PanierUtil from '../utils/PanierUtil';

export default function AjoutArticleScreen({ navigation }: any) {

    const LOCAL_API_ADRESS = "http://192.168.0.48:8000";


    const [scanned, setScanned] = useState(false);
    const [inputText, setInputText] = useState<undefined|string>(undefined);

    const [PermissionOk, setPermissionOk] = useState(false);
    useEffect(() => {
        const getPermission = async () => {
            const {status} = await BarCodeScanner.requestPermissionsAsync();
            setPermissionOk(status === 'granted');
        };
        getPermission();
    }, []);

    const handleBarCodeScanned = async ({type, data}: { type: string, data: string }) => {
        setScanned(true);
        const supposedId = data.replace("item_id=", '');
        await itemDansPanier(supposedId);
    };

    const itemDansPanier = async (itemId: string) => {
        if ( isNaN(parseInt(itemId)) )
        {
            alert('Article introuvable, essayez à nouveau.');
            return;
        }

        let rep;
        try
        {
            rep = await fetch(`${LOCAL_API_ADRESS}/items/${itemId}`, {
                method: 'GET',
            });
        }
        catch(e)
        {
            return;
        }

        const ret = await rep.json();

        if ( !ret )
        {
            alert('Article introuvable.');
            return;
        }
        else
        {
            const id = ret.id;
            await PanierUtil.ajoutPanier(id);
            alert('Article ajouté au panier');
        }


    };

    return (
        <View style={styles.container}>
            {
                PermissionOk ?
                    <BarCodeScanner
                        onBarCodeScanned={ scanned ? undefined : handleBarCodeScanned}
                        style={styles.barcode}
                    />
                    :
                    (
                        <View>
                            <TextInput onChangeText={setInputText} value={inputText} placeholder="Item ID" keyboardType="numeric" />
                            <Button title='Ajouter au panier' onPress={() => {itemDansPanier(inputText!)}} />
                        </View>
                    )
            }
            { scanned && <Button title='Tap to scan again' onPress={() => { setScanned(false) } } /> }
            <Button
                title={PermissionOk ? "Ajouter manuellement le produit" : "Scanner le QR code"}
                onPress={() => setPermissionOk(!PermissionOk)}
            />
            <Button
                title="Panier"
                onPress={() => navigation.navigate('shoppingCart')}
            />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: 'flex',
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'center',
    },
    barcode: {
        flex: 1,
        backgroundColor: 'transparent',
    },
    input: {
        height: 40,
        margin: 12,
        borderWidth: 1,
        padding: 10,
    },

    button: {
        alignItems: 'center',
        justifyContent: 'center',
        paddingVertical: 12,
        paddingHorizontal: 32,
        borderRadius: 4,
        elevation: 3,
        backgroundColor: 'black',
    },
    text: {
        fontSize: 16,
        lineHeight: 21,
        fontWeight: 'bold',
        letterSpacing: 0.25,
        color: 'white',
    },


});

