import React, { useState, useEffect } from 'react';
import { Text, View, StyleSheet, Button } from 'react-native';
import PanierUtil from '../utils/PanierUtil';

export default function PanierScreen({navigation}: any) {

    const [panier, setPanier] = useState<{id: string, name: string, price: number, inCart:number}[]>([]);
    const updatePanier = () => {
        PanierUtil.getProduits().then(panier => {
            setPanier(panier);
        });
    }

    useEffect(() => {
        updatePanier();
    }, []);



    return (
        <View style={styles.container}>
            {panier.map((item: {id: string, name: string, price: number, inCart:number}) => {
                return (
                    <View>
                        <Text key={item.id}>
                            {item.name} - x{item.inCart} : {item.inCart * item.price}$
                        </Text>

                        <View style={styles.buttonsContainer}>
                            <Button
                                containerStyle={{
                                    width: 200,
                                    marginHorizontal: 50,
                                    marginVertical: 10,
                                }}
                                title="-" onPress={ () => {
                                PanierUtil.retirerProduit(item.id);
                                updatePanier();
                            } }
                                type="clear"
                                titleStyle={{ color: 'rgba(78, 116, 289, 1)' }}/>


                        <Button
                            containerStyle={{
                                width: 200,
                                marginHorizontal: 50,
                                marginVertical: 10,
                            }}
                            title="+" onPress={ () => {
                            PanierUtil.ajoutPanier(item.id);
                            updatePanier();
                        } }
                            type="clear"
                            titleStyle={{ color: 'rgba(78, 116, 289, 1)' }}/>
                        </View>
                    </View>
                );
            })}

            <Button title='Payer' onPress={async () => navigation.navigate('checkout', { cart: await PanierUtil.getProduits() })}  />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'center',
    },

    contentView: {
        flex: 1,
    },
    buttonsContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
        alignItems: 'center',
        width: '100%',
        marginVertical: 20,
    },
    subHeader: {
        backgroundColor : "#2089dc",
        color : "white",
        textAlign : "center",
        paddingVertical : 5,
        marginBottom : 10
    }

});