/**
 * PanierUtil.tsx
 * @author Mattias EYHERABIDE
 */

import * as SecureStore from 'expo-secure-store';


const LOCAL_API_ADRESS = "http://192.168.0.48:8000";

let panier: { [key: string]: number } = {};

(async () => {
    const savePanier = await SecureStore.getItemAsync("myAppCart");

    if ( savePanier && savePanier !== '' ) panier = JSON.parse(savePanier);
})();

const enregPanier = () => {
    return SecureStore.setItemAsync("myAppCart", JSON.stringify(panier));
}

export default {

    getProduits: async () => {
        const items: {id: string, name: string, price: number, inCart: number}[] = [];
        for ( const itemId in panier ) {
            let response;
            try {
                response = await fetch(`${LOCAL_API_ADRESS}/items/${itemId}`, {
                    method: 'GET',
                });
            } catch(e) {
                alert(e);
                return;
            }

            const item: {id: string, name: string, price: number} = await response.json();

            if ( !response.ok ) {
                alert('erreur');
                return;
            }

            if ( item ) {
                const itemData: {id: string, name: string, price: number, inCart: number} = {
                    ...item,
                    inCart: panier[itemId]
                };
                items.push(itemData);
            }
        }

        console.log(items);
        return items;
    },

    ajoutPanier: (itemId: string) => {
        if ( panier[itemId] ) panier[itemId]++;
        else { panier[itemId] = 1 }
        return enregPanier();
    },

    retirerProduit: (itemId: string)=>{
        panier[itemId]--;
        if (panier[itemId] <= 0)
            delete panier[itemId];
        return enregPanier();
    }
};